import React, {FC, useMemo} from "react";
import styled from "styled-components";
import {TypeAnimation} from "react-type-animation";

export type TUsersList = {
  users: string[];
  round: number;
}

const emoji = ["😡", "😈", "😬", "🤪", "🤓", "😎", "🥸", "🤯", "😳", "🤬", "🫡", "🫠", "💀", "👽", "🤖"]

const UsersList: FC<TUsersList> = ({
  users,
  round,
}) => {
  const usersSequence = useMemo(() => {
    const copyEmoji = [...emoji];
    const getRandomEmoji = () => {
      const idx = Math.floor(Math.random() * (copyEmoji.length - 1));
      const result = copyEmoji[idx];
      copyEmoji.splice(idx, 1);
      return result;
    }

    let result = `===========    LAST ROUND!   ===========\n==========    List start    ==========\n\n\n`;

    for (let i = 0; i < users.length; i++) {
      result += `${i + 1}) ${users[i]} ${getRandomEmoji()}\n\n`;
    }

    result += "\n===========    List end    ===========";

    return result;
  }, [round, users]);

  return (
    <Wrapper>
      <Content>
        <TypeAnimation
          style={{ whiteSpace: 'pre-line', display: 'block', color: "#0F0", fontSize: "5vmin", opacity: 0.8 }}
          sequence={[usersSequence]}
           // @ts-ignore
          speed={70}
        />
      </Content>
    </Wrapper>
  );
}

const Wrapper = styled.div`
  position: absolute;
  display: flex;
  justify-content: center;
  top: 70px;
  bottom: 70px;
  left: 300px;
  right: 300px;
  background: #000;
  padding: 50px;
  border-radius: 5px;
  box-shadow: 0 0 10px #0fa, 0 0 45px #0F0, 0 0 55px #0fa;
`;

const Content = styled.div`
  width: 100%;
`;

export default UsersList;
